@@ -1,5 +1,4 @@
 import unittest
-from mindsdb_native import Predictor, F
 from common import DB_CREDENTIALS
 from mindsdb_datasources import MongoDS
 
@@ -25,8 +24,6 @@ class TestMongoDB(unittest.TestCase):
             database=self.DATABASE
         )
 
-        F.analyse_dataset(from_data=mongodb_ds)
-
         for val in mongodb_ds.filter([['location', 'like','ood']])['location']:
             assert val == 'good'
 
